pub trait StationaryEigenProblem<const N: usize> {
// Required method
fn operator(&self, grid: &Grid<N>) -> CsrMatrix;
}Expand description
A symmetric linear operator whose principal eigenvector is a stationary value.
The operator is stored in the sign convention used by the exact reference:
for the Avellaneda-Stoikov GLT matrix this is the negated matrix
diag(-alpha q^2) + offdiag(+eta) whose Perron eigenvector is the
long-horizon limit.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".